@@ -1,7 +1,7 @@
 # proc: Simple interface to Linux process information.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: June 13, 2016
+# Last Change: April 26, 2020
 # URL: https://proc.readthedocs.io
 
 """
@@ -31,14 +31,34 @@ import time
 from executor import which
 from proc.unix import UnixProcess
 from property_manager import lazy_property
+from humanfriendly.deprecation import define_aliases
+
+# Public identifiers that require documentation.
+__all__ = (
+    'NUM_RACE_CONDITIONS',
+    'OwnerIDs',
+    'Process',
+    'ProtectedAccess',
+    'find_processes',
+    'find_system_uptime',
+    'gid_to_name',
+    'logger',
+    'parse_process_cmdline',
+    'parse_process_status',
+    'sorted_by_pid',
+    'uid_to_name',
+)
 
 # Initialize a logger.
 logger = logging.getLogger(__name__)
 
-# Global counters to track the number of detected race conditions. This is only
-# useful for the test suite, because I want the test suite to create race
-# conditions and verify that they are properly handled.
-num_race_conditions = dict(cmdline=0, environ=0, exe=0, stat=0, status=0)
+NUM_RACE_CONDITIONS = dict(cmdline=0, environ=0, exe=0, stat=0, status=0)
+"""
+A dictionary with string keys and integer values that's used to keep global
+counters that track the number of detected race conditions. This is only useful
+for the test suite, because it intentionally creates race conditions to verify
+that they are properly handled.
+"""
 
 
 class Process(UnixProcess):
@@ -278,6 +298,30 @@ class Process(UnixProcess):
         """
         return self.cmdline
 
+    @property
+    def cwd(self):
+        """
+        The working directory of the process (a string or :data:`None`).
+
+        **Availability:**
+
+        - This property is constructed by dereferencing the symbolic link
+          ``/proc/[pid]/cwd`` each time the property is referenced (because the
+          working directory may change at any time).
+
+        - If this property is referenced after the process has ended then it's
+          too late to dereference the symbolic link and an empty string is
+          returned.
+
+        - If an exception is encountered while dereferencing the symbolic link
+          (for example because you don't have permission to dereference the
+          symbolic link) the exception is swallowed and an empty string is
+          returned.
+        """
+        with ProtectedAccess('cwd', "dereference working directory"):
+            return os.readlink(os.path.join(self.proc_tree, 'cwd'))
+        return ''
+
     @lazy_property
     def environ(self):
         """
@@ -434,8 +478,8 @@ class Process(UnixProcess):
 
         See also :func:`~proc.unix.UnixProcess.suspend()`,
         :func:`~proc.unix.UnixProcess.resume()`,
-        :func:`~executor.process.ControllableProcess.terminate()` and
-        :func:`~executor.process.ControllableProcess.kill()`.
+        :meth:`~executor.process.ControllableProcess.terminate()` and
+        :meth:`~executor.process.ControllableProcess.kill()`.
         """
         stat_fields = parse_process_status(self.proc_tree, silent=True)
         return bool(stat_fields and stat_fields[2] != 'Z')
@@ -832,7 +876,7 @@ class ProtectedAccess(object):
         """
         Initialize a :class:`ProtectedAccess` object.
 
-        :param key: The key in :data:`num_race_conditions` (a string).
+        :param key: The key in :data:`NUM_RACE_CONDITIONS` (a string).
         :param action: A verb followed by a noun describing what kind of access
                        is being protected (a string)
         """
@@ -860,9 +904,17 @@ class ProtectedAccess(object):
                     #  - ESRCH is reported when /proc/[pid]/stat disappears.
                     logger.debug("Failed to %s due to race condition! (%s)",
                                  self.action, filename)
-                    num_race_conditions[self.key] += 1
+                    NUM_RACE_CONDITIONS[self.key] += 1
                     return True
             # Other exceptions are logged and swallowed.
             logger.warning("Failed to %s because of unexpected exception! (%s)",
                            self.action, filename, exc_info=(exc_type, exc_value, traceback))
         return True
+
+
+# Define aliases for backwards compatibility.
+define_aliases(
+    module_name=__name__,
+    # In proc 1.0 the following module variable was renamed.
+    num_race_conditions='proc.core.NUM_RACE_CONDITIONS',
+)
