@@ -1,7 +1,7 @@
 # Automated tests for the `proc' package.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: June 24, 2017
+# Last Change: June 21, 2018
 # URL: https://proc.readthedocs.io
 
 """Test suite for the `proc` package."""
@@ -69,6 +69,7 @@ class ProcTestCase(TestCase):
         assert process.pgrp == os.getpgrp(), "Unexpected process group ID!"
         assert process.user_ids.real == os.getuid(), "Unexpected real user ID!"
         assert process.group_ids.real == os.getgid(), "Unexpected real group ID!"
+        assert process.cwd == os.getcwd(), "Unexpected working directory!"
         # The following assertion may fail at some point, but I chose it above
         # using uid_to_name(os.getuid()) because the latter isn't testing
         # anything useful at all ...
@@ -86,7 +87,9 @@ class ProcTestCase(TestCase):
             "First token in process command line isn't executable?!"
         assert executable(process.exe), "Process executable pathname (based on /proc/[pid]/stat) invalid?!"
         assert executable(process.exe_path), "Process executable pathname (fall back option) invalid?!"
-        assert which(process.exe_name), "Process executable base name (fall back option) not available on $PATH?!"
+        if not (os.environ.get('TRAVIS') and process.exe_name == 'pypy'):
+            # https://travis-ci.org/xolox/python-proc/jobs/395176218
+            assert which(process.exe_name), "Process executable base name (fall back option) not available on $PATH?!"
         assert process.is_alive, "The current process is not running?! :-P"
         # Python's standard library doesn't seem to expose process session IDs
         # so all I can test reliably is that the session ID is an integer...
@@ -354,7 +357,7 @@ class ProcTestCase(TestCase):
 
     def test_apache_worker_monitoring(self):
         """Test the :mod:`proc.apache` module."""
-        if not os.path.exists('/etc/apache2/sites-enabled/proc-test-vhost'):
+        if not os.path.exists('/etc/apache2/sites-enabled/proc-test-vhost.conf'):
             return self.skipTest("Apache worker monitoring test disabled except on Travis CI!")
         worker_rss, wsgi_rss = find_apache_memory_usage()
         # Make sure some regular Apache workers were identified.
